@@ -238,12 +238,13 @@ class Database:
             year_month_involved_list.append((datetime.datetime.strptime(year_month_involved_list[-1], '%y%m') + relativedelta(months=1)).strftime('%y%m'))
 
             year_month_involved_list_str = json.dumps(str(year_month_involved_list))
-            year_month_involved_list_str = year_month_involved_list_str.replace('[', '', regex=False)
-            year_month_involved_list_str = year_month_involved_list_str.replace(']', '', regex=False)
-            year_month_involved_list_str = year_month_involved_list_str.replace('\'', '', regex=False)
-            year_month_involved_list_str = year_month_involved_list_str.replace(',', '', regex=False)
-            year_month_involved_list_str = year_month_involved_list_str.replace(' ', '_', regex=False)
-            year_month_involved_list_str = year_month_involved_list_str.replace('\"', '', regex=False)
+
+            year_month_involved_list_str = year_month_involved_list_str.replace('[', '')
+            year_month_involved_list_str = year_month_involved_list_str.replace(']', '')
+            year_month_involved_list_str = year_month_involved_list_str.replace('\'', '')
+            year_month_involved_list_str = year_month_involved_list_str.replace(',', '')
+            year_month_involved_list_str = year_month_involved_list_str.replace(' ', '_')
+            year_month_involved_list_str = year_month_involved_list_str.replace('\"', '')
 
             link_url = 'http://www.hkfdb.net/data_api?'
             token_str = 'token=' + str(self.authToken)
@@ -465,6 +466,8 @@ class Database:
                 df['date'] = pd.to_datetime(df['date'],format='%Y-%m-%d')
                 df = df[['date','code','issued_share_mil','market_cap_mil','cumulative_market_cap_mil']]
                 df = df.set_index('date')
+                df = df[~df.index.duplicated(keep='first')]
+
                 return df
 
         else:
